@@ -61,6 +61,7 @@ const nsIWindowWatcher       = Components.interfaces.nsIWindowWatcher;
 const nsICategoryManager     = Components.interfaces.nsICategoryManager;
 const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
+const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
 
 const NS_BINDING_ABORTED = 0x804b0002;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
@@ -202,14 +203,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 213 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 214 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 220 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 221 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -222,7 +223,7 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 245 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 246 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -282,6 +283,7 @@ var nsBrowserContentHandler = {
         !iid.equals(nsICommandLineHandler) &&
         !iid.equals(nsIBrowserHandler) &&
         !iid.equals(nsIContentHandler) &&
+        !iid.equals(nsICommandLineValidator) &&
         !iid.equals(nsIFactory))
       throw Components.errors.NS_ERROR_NO_INTERFACE;
 
@@ -429,7 +431,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 464 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 466 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -573,6 +575,21 @@ var nsBrowserContentHandler = {
     request.cancel(NS_BINDING_ABORTED);
   },
 
+  /* nsICommandLineValidator */
+  validate : function bch_validate(cmdLine) {
+    // Other handlers may use osint so only handle the osint flag if the url
+    // flag is also present and the command line is valid.
+    var osintFlagIdx = cmdLine.findFlag("osint", false);
+    var urlFlagIdx = cmdLine.findFlag("url", false);
+    if (urlFlagIdx > -1 && (osintFlagIdx > -1 ||
+        cmdLine.state == nsICommandLine.STATE_REMOTE_EXPLICIT)) {
+      var urlParam = cmdLine.getArgument(urlFlagIdx + 1);
+      if (cmdLine.length != urlFlagIdx + 2 || /firefoxurl:/.test(urlParam))
+        throw NS_ERROR_ABORT;
+      cmdLine.handleFlag("osint", false)
+    }
+  },
+
   /* nsIFactory */
   createInstance: function bch_CI(outer, iid) {
     if (outer != null)
@@ -630,13 +647,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 667 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 684 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 693 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 710 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -786,9 +803,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 843 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 860 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 845 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 862 "/usr/obj/ports/mozilla-firefox-2.0.0.6-debug/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
@@ -813,6 +830,9 @@ var Module = {
     catMan.addCategoryEntry("command-line-handler",
                             "x-default",
                             dch_contractID, true, true);
+    catMan.addCategoryEntry("command-line-validator",
+                            "b-browser",
+                            bch_contractID, true, true);
   },
     
   unregisterSelf : function mod_unregself(compMgr, location, type) {
@@ -827,6 +847,8 @@ var Module = {
                                "m-browser", true);
     catMan.deleteCategoryEntry("command-line-handler",
                                "x-default", true);
+    catMan.deleteCategoryEntry("command-line-validator",
+                               "b-browser", true);
   },
 
   canUnload: function(compMgr) {
